# OPS02-BP03: Operations activities have identified owners

## Description

Các hoạt động vận hành cần được phân công rõ ràng.

## Implementation Guidance

- Define on-call rotations
- Assign owners for operational activities
- Document operational responsibilities
- Clear handoff procedures
- Regular review of operational assignments

## Risk Level

Medium - Unclear ownership leads to delayed responses.
